@@ -329,7 +329,9 @@ selection_table <- function(X, max.dur = 10, path = NULL, whole.recs = FALSE,
   }
 
   if (skip.error & length(error_files) > 0) {
-    message2(color = "silver", x = paste("\nthe following file(s) couldn't be read and were not included:", cli::style_bold(paste(error_files, collapse = ","))))
+    message2(color = "silver", x = "One or more file(s) couldn't be read and were not included (run .Options$unread_files to see which files)")
+    
+    on.exit(options(unread_files = error_files))
   }
 
   return(X)
@@ -503,7 +505,7 @@ is_extended_selection_table <- function(x) inherits(x, "extended_selection_table
 
   if (is.data.frame(Y)) {
     # subset wave objects in attributes
-    attributes(Y)$wave.objects <- attributes(X)$wave.objects[names(attributes(X)$wave.objects) %in% Y$sound.files]
+    attributes(Y)$wave.objects <- attributes(X)$wave.objects[names(attributes(X)$wave.objects) %in% unique(Y$sound.files)]
 
     attributes(Y)$check.results <-
       attributes(X)$check.results[paste(attributes(X)$check.results$sound.files, attributes(X)$check.results$selec) %in% paste(Y$sound.files, Y$selec), ]
@@ -565,12 +567,19 @@ print.extended_selection_table <- function(x, ...) {
 
   message2(color = "silver", x = paste0("\n* ", length(attr(x, "wave.objects")), " wave object(s) (as attributes): "))
 
-  message2(color = "silver", x = head(names(attr(x, "wave.objects"))))
+  if (length(attr(x, "wave.objects")) <= 6)
+  message2(color = "silver", x = paste(names(attr(x, "wave.objects")), collapse = ", ")) else
+    message2(color = "silver", x = paste(names(attr(x, "wave.objects"))[1:6], collapse = ", "))
 
   if (length(attr(x, "wave.objects")) > 6) message2(color = "silver", x = paste0("... and ", length(attr(x, "wave.objects")) - 6, " more"))
-
-  message2(color = "silver", x = "\n* A data frame (check.results) generated by check_sels() (as attribute)")
-
+  
+  if (length(attr(x, "wave.objects")) != length(unique(x$sound.files))) message2(color = "red", x = paste0("(warning: the number of wave objects (", length(attr(x, "wave.objects")), ") differs from the number of sound files in the \nextended selection table (", length(unique(x$sound.files)), ")- the acoustic data seems to be corrupted)"))
+  
+  message2(color = "silver", x = paste("\n* A data frame (check.results) with", nrow(attr(x, "check.results")), "rows generated by check_sels() (as attribute)"))
+  if (nrow(x) != nrow(attr(x, "check.results"))) {
+    message2(color = "red", x = paste0("(warning: the number of rows in 'check.results' (", nrow(attr(x, "check.results")), ") differs from those in the \nextended selection table (", nrow(x), ")- the metadata seems to be corrupted)"))
+  }
+  
   if (attr(x, "by.song")[[1]]) {
     message2(color = "silver", x = paste0(cli::style_bold("\nAdditional information:"), "\n* The selection table was created", cli::style_italic(cli::style_bold(" by song ")), "(see 'class_extended_selection_table')"))
   } else {
@@ -640,9 +649,13 @@ print.selection_table <- function(x, ...) {
   }
   if (nrow(x) > 6) message2(color = "silver", x = paste0(if (ncol(x) <= 6) "..." else "", " and ", nrow(x) - 6, " more row(s)"))
 
-
-  message2(color = "silver", x = "\n * A data frame (check.results) generated by check_sels() (as attribute) ")
-
+ 
+    message2(color = "silver", x = paste("\n* A data frame (check.results) with", nrow(attr(x, "check.results")), "rows generated by check_sels() (as attribute)"))
+  
+    if (nrow(x) != nrow(attr(x, "check.results"))) {
+    message2(color = "red", x = paste0("(warning: the number of rows in 'check.results' (", nrow(attr(x, "check.results")), ") differs from those in the \nselection table (", nrow(x), ")- the metadata seems to be corrupted)"))
+  }
+  
   # print warbleR version
   if (!is.null(attr(x, "warbleR.version"))) {
     message2(color = "silver", x = paste0("created by warbleR ", attr(x, "warbleR.version")))
